==> chromattic.core-1.0.0-beta3-sources.jar: org/chromattic/core/mapper/onetomany/hierarchical/AnyChildMultiValueMapper.java <==
/*
 * Copyright (C) 2003-2009 eXo Platform SAS.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.chromattic.core.mapper.onetomany.hierarchical;

import org.chromattic.core.ObjectContext;
import org.chromattic.common.BufferingList;

/**
 * @author <a href="mailto:julien.viet@exoplatform.com">Julien Viet</a>
 * @version $Revision$
 */
public abstract class AnyChildMultiValueMapper {

  abstract <E> Object createValue(ObjectContext parentCtx, Class<E> relatedClass);

  public static class Map extends AnyChildMultiValueMapper {
    <E> Object createValue(ObjectContext parentCtx, Class<E> relatedClass) {
      return new AnyChildMap<E>(parentCtx, relatedClass);
    }
  }

  public static class Collection extends AnyChildMultiValueMapper {
    <E> Object createValue(ObjectContext parentCtx, Class<E> relatedClass) {
      return new AnyChildCollection<E>(parentCtx, relatedClass);
    }
  }

  public static class List extends AnyChildMultiValueMapper {
    <E> Object createValue(ObjectContext parentCtx, Class<E> relatedClass) {
      return new AnyChildList<E>(parentCtx, relatedClass);
    }
  }
}

==> chromattic.core-1.1.0-beta3-sources.jar: org/chromattic/core/mapper/onetomany/hierarchical/AnyChildMultiValueMapper.java <==
/*
 * Copyright (C) 2003-2009 eXo Platform SAS.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.chromattic.core.mapper.onetomany.hierarchical;

import org.chromattic.core.EntityContext;

/**
 * @author <a href="mailto:julien.viet@exoplatform.com">Julien Viet</a>
 * @version $Revision$
 */
public abstract class AnyChildMultiValueMapper {

  public abstract <E> Object createValue(EntityContext parentCtx, String prefix, Class<E> relatedClass);

  public static class Map extends AnyChildMultiValueMapper {
    public <E> Object createValue(EntityContext parentCtx, String prefix, Class<E> relatedClass) {
      return new AnyChildMap<E>(parentCtx, prefix, relatedClass);
    }
  }

  public static class Collection extends AnyChildMultiValueMapper {
    public <E> Object createValue(EntityContext parentCtx, String prefix, Class<E> relatedClass) {
      return new AnyChildCollection<E>(parentCtx, prefix, relatedClass);
    }
  }

  public static class List extends AnyChildMultiValueMapper {
    public <E> Object createValue(EntityContext parentCtx, String prefix, Class<E> relatedClass) {
      return new AnyChildList<E>(parentCtx, prefix, relatedClass);
    }
  }
}
